aboutsummaryrefslogtreecommitdiffstats
path: root/src/cryptography/hazmat/backends/interfaces.py
diff options
context:
space:
mode:
authorPaul Kehrer <paul.l.kehrer@gmail.com>2015-08-06 12:37:10 +0100
committerPaul Kehrer <paul.l.kehrer@gmail.com>2015-08-06 12:38:40 +0100
commit1ae7653fcb027ddc0b201d50a011678c93186b11 (patch)
tree8a5d14ee9c1e43e873c035d66d97c07a9d375732 /src/cryptography/hazmat/backends/interfaces.py
parent304d9386d4a6e92325a0952b356f30e34562b446 (diff)
downloadcryptography-1ae7653fcb027ddc0b201d50a011678c93186b11.tar.gz
cryptography-1ae7653fcb027ddc0b201d50a011678c93186b11.tar.bz2
cryptography-1ae7653fcb027ddc0b201d50a011678c93186b11.zip
rename sign_x509_certificate backend method to create_x509_certificate
Diffstat (limited to 'src/cryptography/hazmat/backends/interfaces.py')
-rw-r--r--src/cryptography/hazmat/backends/interfaces.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cryptography/hazmat/backends/interfaces.py b/src/cryptography/hazmat/backends/interfaces.py
index 49ccda18..a43621a7 100644
--- a/src/cryptography/hazmat/backends/interfaces.py
+++ b/src/cryptography/hazmat/backends/interfaces.py
@@ -281,9 +281,9 @@ class X509Backend(object):
"""
@abc.abstractmethod
- def sign_x509_certificate(self, builder, private_key, algorithm):
+ def create_x509_certificate(self, builder, private_key, algorithm):
"""
Sign an X.509 Certificate from a CertificateBuilder object.
"""
@@ -281,9 +281,9 @@ class X509Backend(object):
"""
- Sign an X.509 Certificate from a CertificateBuilder object.
+ Create and sign an X.509 certificate from a CertificateBuilder object.
"""